<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2023 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Controller;

use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Filesystem\File;
use _JchOptimizeVendor\Psr\Log\LoggerAwareInterface;
use _JchOptimizeVendor\Psr\Log\LoggerAwareTrait;
use JchOptimize\Model\BulkSettings;

class ExportSettings extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;
    private BulkSettings $bulkSettings;

    public function __construct(BulkSettings $bulkSettings)
    {
        $this->bulkSettings = $bulkSettings;
        parent::__construct();
    }

    public function execute()
    {
        $file = $this->bulkSettings->exportSettings();
        if (\file_exists($file)) {
            \header('Content-Description: FileTransfer');
            \header('Content-Type: application/json');
            \header('Content-Disposition: attachment; filename="'.\basename($file).'"');
            \nocache_headers();
            \header('Content-Length: '.\filesize($file));
            \ob_clean();
            \flush();
            \readfile($file);
            File::delete($file);

            exit;
        }
    }
}
