<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2023 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Controller;

use _JchOptimizeVendor\GuzzleHttp\Psr7\UploadedFile;
use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use _JchOptimizeVendor\Psr\Log\LoggerAwareInterface;
use _JchOptimizeVendor\Psr\Log\LoggerAwareTrait;
use JchOptimize\Model\BulkSettings;

class ImportSettings extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;
    private BulkSettings $bulkSettings;

    public function __construct(BulkSettings $bulkSettings, ?Input $input = null)
    {
        $this->bulkSettings = $bulkSettings;
        parent::__construct($input);
    }

    public function execute()
    {
        $file = $this->getInput()->files->get('file', []);
        if (empty($file)) {
            $this->logger->error(\__('No file was uploaded'));
            $this->redirect();
        }
        $uploadErrorMap = [\UPLOAD_ERR_OK => \__('File uploaded successfully'), \UPLOAD_ERR_INI_SIZE => \__('File exceeded the limit set in php.ini'), \UPLOAD_ERR_FORM_SIZE => \__('File exceeded the value set in form'), \UPLOAD_ERR_PARTIAL => \__(' File was only partially uploaded'), \UPLOAD_ERR_NO_FILE => \__('No file was uploaded'), \UPLOAD_ERR_NO_TMP_DIR => \__('No tmp directory configured for file upload'), \UPLOAD_ERR_CANT_WRITE => \__('Upload directory not writable'), \UPLOAD_ERR_EXTENSION => \__('An unknown extension prevented the file from being loaded')];

        try {
            $uploadedFile = new UploadedFile($file['tmp_name'], $file['size'], $file['error'], $file['name'], $file['type']);
            if (\UPLOAD_ERR_OK !== $uploadedFile->getError()) {
                throw new \Exception($uploadErrorMap[$uploadedFile->getError()]);
            }
        } catch (\Exception $exception) {
            $this->logger->error(\sprintf(\__('Error uploaded file: %s'), $exception->getMessage()));
            $this->redirect();
        }

        try {
            $this->bulkSettings->importSettings($uploadedFile);
        } catch (\Exception $exception) {
            $this->logger->error(\sprintf(\__('Error importing settings: %s'), $exception->getMessage()));
        }
        $this->logger->success(\__('Settings successfully imported'));
        $this->redirect();
    }

    private function redirect()
    {
        \wp_redirect('options-general.php?page=jch_optimize');

        exit;
    }
}
