<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Controller;

use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use _JchOptimizeVendor\Psr\Log\LoggerAwareInterface;
use _JchOptimizeVendor\Psr\Log\LoggerAwareTrait;
use JchOptimize\Core\Admin\Icons;
use JchOptimize\Model\Configure;
use JchOptimize\Platform\Utility;

class ToggleSetting extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;

    private Configure $model;

    public function __construct(Configure $model, ?Input $input = null)
    {
        $this->model = $model;
        parent::__construct($input);
    }

    public function execute()
    {
        $setting = $this->getInput()->get('setting');
        $this->model->toggleSetting($setting);
        $currentSettingValue = $this->model->getState()->get($setting);
        if ('integrated_page_cache_enable' == $setting) {
            $currentSettingValue = Utility::isPageCacheEnabled($this->model->getState());
        }
        $class = $currentSettingValue ? 'enabled' : 'disabled';
        $class2 = '';
        $auto = \false;
        if ('pro_reduce_unused_css' == $setting) {
            $class2 = $this->model->getState()->get('optimizeCssDelivery_enable') ? 'enabled' : 'disabled';
        }
        if ('optimizeCssDelivery_enable' == $setting) {
            $class2 = $this->model->getState()->get('pro_reduce_unused_css') ? 'enabled' : 'disabled';
        }
        if ('combine_files_enable' == $setting && $currentSettingValue) {
            $auto = $this->getEnabledAutoSetting();
        }
        echo \json_encode(['class' => $class, 'class2' => $class2, 'auto' => $auto]);

        exit;
    }

    private function getEnabledAutoSetting()
    {
        $autoSettingsMap = Icons::autoSettingsArrayMap();
        $autoSettingsInitialized = \array_map(function () {
            return '0';
        }, $autoSettingsMap);
        $currentAutoSettings = \array_intersect_key($this->model->getState()->toArray(), $autoSettingsInitialized);
        // order array
        $orderedCurrentAutoSettings = \array_merge($autoSettingsInitialized, $currentAutoSettings);
        $autoSettings = ['minimum', 'intermediate', 'average', 'deluxe', 'premium', 'optimum'];
        for ($j = 0; $j < 6; ++$j) {
            if (\array_values($orderedCurrentAutoSettings) === \array_column($autoSettingsMap, 's'.($j + 1))) {
                return $autoSettings[$j];
            }
        }
        // No auto setting configured
        return \false;
    }
}
